from setuptools import setup

setup(
    name = 'error-alerts',
    packages = ['alerts'],
    version = '1',
    description = 'Error alerts via Telegram',
    url = 'https://github.com/xjxckk/error-alerts/',
    download_url = 'https://github.com/xjxckk/error-alerts/archive/refs/tags/v1.tar.gz',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown'
    )


import traceback, telegram

class setup:
    def __init__(self, telegram_token, telegram_channel, full_error=False):
        self.bot = telegram.Bot(token=telegram_token)
        self.channel = telegram_channel
        self.full_error = full_error
    def send(self, title, exception):
        error = str(exception)
        if self.full_error:
            error = traceback.format_exc()
        message = f'{title}: {error}'
        self.bot.send_message(self.channel, message)
        print(message)
        print()